import google.datalab.bigquery as bq

def execute_query(queryStr, dataset):
  query = bq.Query(queryStr.format(dataset))
  outputOptions = bq.QueryOutput.table(use_cache=False)
  return query.execute(output_options=outputOptions).result()

def execute_query(client, queryStr, dataset, queryParams):
  query = queryStr.format(dataset)
  jobConfig = bq.QueryJobConfig()
  jobConfig.query_parameters = queryParams
  queryJob = client.query(
      query,
      job_config=jobConfig)  
  return queryJob.result()


import setuptools

setuptools.setup(
    name="dglab2018",
    version="0.0.10",
    author="Dominik Gotojuch",
    author_email="dominik@gotojuch.com",
    description="Data processing and analysis scripts supporting the PhD project by one Dominik Gotojuch",
    url="https://github.com/robotgentleman/dglab2018",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)